import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Wavefront Cloud Integration for Microsoft Azure. This allows Azure cloud integrations to be created,
 * updated, and deleted.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * const azureActivityLog = new wavefront.CloudIntegrationAzureActivityLog("azure_activity_log", {
 *     name: "Test Integration",
 *     clientId: "client-id2",
 *     clientSecret: "client-secret2",
 *     tenant: "my-tenant2",
 * });
 * ```
 *
 * ## Import
 *
 * Azure Cloud Integrations can be imported by using the `id`, e.g.:
 *
 * ```sh
 * $ pulumi import wavefront:index/cloudIntegrationAzure:CloudIntegrationAzure azure a411c16b-3cf7-4f03-bf11-8ca05aab898d
 * ```
 */
export declare class CloudIntegrationAzure extends pulumi.CustomResource {
    /**
     * Get an existing CloudIntegrationAzure resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CloudIntegrationAzureState, opts?: pulumi.CustomResourceOptions): CloudIntegrationAzure;
    /**
     * Returns true if the given object is an instance of CloudIntegrationAzure.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CloudIntegrationAzure;
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    readonly additionalTags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * A list of Azure Activity Log categories.
     */
    readonly categoryFilters: pulumi.Output<string[] | undefined>;
    /**
     * Client ID for an Azure service account within your project.
     */
    readonly clientId: pulumi.Output<string>;
    /**
     * Client secret for an Azure service account within your project.
     */
    readonly clientSecret: pulumi.Output<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    readonly forceSave: pulumi.Output<boolean | undefined>;
    /**
     * A regular expression that a metric name must match (case-insensitively) in order to be ingested.
     */
    readonly metricFilterRegex: pulumi.Output<string | undefined>;
    /**
     * The human-readable name of this integration.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A list of Azure resource groups from which to pull metrics.
     */
    readonly resourceGroupFilters: pulumi.Output<string[] | undefined>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    readonly service: pulumi.Output<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    readonly serviceRefreshRateInMinutes: pulumi.Output<number | undefined>;
    /**
     * Tenant ID for an Azure service account within your project.
     */
    readonly tenant: pulumi.Output<string>;
    /**
     * Create a CloudIntegrationAzure resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CloudIntegrationAzureArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CloudIntegrationAzure resources.
 */
export interface CloudIntegrationAzureState {
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    additionalTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * A list of Azure Activity Log categories.
     */
    categoryFilters?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Client ID for an Azure service account within your project.
     */
    clientId?: pulumi.Input<string>;
    /**
     * Client secret for an Azure service account within your project.
     */
    clientSecret?: pulumi.Input<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    forceSave?: pulumi.Input<boolean>;
    /**
     * A regular expression that a metric name must match (case-insensitively) in order to be ingested.
     */
    metricFilterRegex?: pulumi.Input<string>;
    /**
     * The human-readable name of this integration.
     */
    name?: pulumi.Input<string>;
    /**
     * A list of Azure resource groups from which to pull metrics.
     */
    resourceGroupFilters?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    service?: pulumi.Input<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    serviceRefreshRateInMinutes?: pulumi.Input<number>;
    /**
     * Tenant ID for an Azure service account within your project.
     */
    tenant?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a CloudIntegrationAzure resource.
 */
export interface CloudIntegrationAzureArgs {
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    additionalTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * A list of Azure Activity Log categories.
     */
    categoryFilters?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Client ID for an Azure service account within your project.
     */
    clientId: pulumi.Input<string>;
    /**
     * Client secret for an Azure service account within your project.
     */
    clientSecret: pulumi.Input<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    forceSave?: pulumi.Input<boolean>;
    /**
     * A regular expression that a metric name must match (case-insensitively) in order to be ingested.
     */
    metricFilterRegex?: pulumi.Input<string>;
    /**
     * The human-readable name of this integration.
     */
    name?: pulumi.Input<string>;
    /**
     * A list of Azure resource groups from which to pull metrics.
     */
    resourceGroupFilters?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    service: pulumi.Input<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    serviceRefreshRateInMinutes?: pulumi.Input<number>;
    /**
     * Tenant ID for an Azure service account within your project.
     */
    tenant: pulumi.Input<string>;
}
