import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Wavefront Derived Metric Resource. This allows derived metrics to be created,
 * updated, and deleted.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * const derived = new wavefront.DerivedMetric("derived", {
 *     name: "dummy derived metric",
 *     minutes: 5,
 *     query: "aliasMetric(5, \"some.metric\")",
 * });
 * ```
 *
 * ## Import
 *
 * Derived Metrics can be imported by using the `id`, e.g.:
 *
 * ```sh
 * $ pulumi import wavefront:index/derivedMetric:DerivedMetric derived_metric 1577102900578
 * ```
 */
export declare class DerivedMetric extends pulumi.CustomResource {
    /**
     * Get an existing DerivedMetric resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DerivedMetricState, opts?: pulumi.CustomResourceOptions): DerivedMetric;
    /**
     * Returns true if the given object is an instance of DerivedMetric.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DerivedMetric;
    /**
     * User-supplied additional explanatory information for the derived metric.
     */
    readonly additionalInformation: pulumi.Output<string | undefined>;
    /**
     * How frequently the query generating the derived metric is run.
     */
    readonly minutes: pulumi.Output<number>;
    /**
     * The name of the Derived Metric in Wavefront.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A Wavefront query that is evaluated at regular intervals (default is 1 minute).
     */
    readonly query: pulumi.Output<string>;
    /**
     * A set of tags to assign to this resource.
     */
    readonly tags: pulumi.Output<string[] | undefined>;
    /**
     * Create a DerivedMetric resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DerivedMetricArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering DerivedMetric resources.
 */
export interface DerivedMetricState {
    /**
     * User-supplied additional explanatory information for the derived metric.
     */
    additionalInformation?: pulumi.Input<string>;
    /**
     * How frequently the query generating the derived metric is run.
     */
    minutes?: pulumi.Input<number>;
    /**
     * The name of the Derived Metric in Wavefront.
     */
    name?: pulumi.Input<string>;
    /**
     * A Wavefront query that is evaluated at regular intervals (default is 1 minute).
     */
    query?: pulumi.Input<string>;
    /**
     * A set of tags to assign to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a DerivedMetric resource.
 */
export interface DerivedMetricArgs {
    /**
     * User-supplied additional explanatory information for the derived metric.
     */
    additionalInformation?: pulumi.Input<string>;
    /**
     * How frequently the query generating the derived metric is run.
     */
    minutes: pulumi.Input<number>;
    /**
     * The name of the Derived Metric in Wavefront.
     */
    name?: pulumi.Input<string>;
    /**
     * A Wavefront query that is evaluated at regular intervals (default is 1 minute).
     */
    query: pulumi.Input<string>;
    /**
     * A set of tags to assign to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
}
