import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to get information about a Wavefront external link by its ID.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the information about a specific external links.
 * const example = wavefront.getExternalLink({
 *     id: "sample-external-link-id",
 * });
 * ```
 */
export declare function getExternalLink(args: GetExternalLinkArgs, opts?: pulumi.InvokeOptions): Promise<GetExternalLinkResult>;
/**
 * A collection of arguments for invoking getExternalLink.
 */
export interface GetExternalLinkArgs {
    /**
     * The ID of the external link.
     */
    id: string;
}
/**
 * A collection of values returned by getExternalLink.
 */
export interface GetExternalLinkResult {
    /**
     * The timestamp in epoch milliseconds indicating when the external link is created.
     */
    readonly createdEpochMillis: number;
    /**
     * The ID of the user who created the external link.
     */
    readonly creatorId: string;
    /**
     * Human-readable description of this link.
     */
    readonly description: string;
    /**
     * The ID of the external link.
     */
    readonly id: string;
    /**
     * Whether this is a "Log Integration" subType of external link.
     */
    readonly isLogIntegration: boolean;
    /**
     * Controls whether a link is displayed in the context menu of a highlighted series. If present, the metric name of the highlighted series must match this regular expression in order for the link to be displayed.
     */
    readonly metricFilterRegex: string;
    /**
     * The name of the external link.
     */
    readonly name: string;
    /**
     * (Optional) Controls whether a link is displayed in the context menu of a highlighted
     * series. This is a map from string to regular expression. The highlighted series must contain point tags whose
     * keys are present in the keys of this map and whose values match the regular expressions associated with those
     * keys in order for the link to be displayed.
     */
    readonly pointTagFilterRegexes: {
        [key: string]: string;
    };
    /**
     * Controls whether a link is displayed in the context menu of a highlighted series. If present, the source name of the highlighted series must match this regular expression in order for the link to be displayed.
     */
    readonly sourceFilterRegex: string;
    /**
     * The mustache template for the link. The template must expand to a full URL, including scheme, origin, etc.
     */
    readonly template: string;
    /**
     * The timestamp in epoch milliseconds indicating when the external link is updated.
     */
    readonly updatedEpochMillis: number;
    /**
     * The ID of the user who updated the external link.
     */
    readonly updaterId: string;
}
/**
 * Use this data source to get information about a Wavefront external link by its ID.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the information about a specific external links.
 * const example = wavefront.getExternalLink({
 *     id: "sample-external-link-id",
 * });
 * ```
 */
export declare function getExternalLinkOutput(args: GetExternalLinkOutputArgs, opts?: pulumi.InvokeOptions): pulumi.Output<GetExternalLinkResult>;
/**
 * A collection of arguments for invoking getExternalLink.
 */
export interface GetExternalLinkOutputArgs {
    /**
     * The ID of the external link.
     */
    id: pulumi.Input<string>;
}
