import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to get information about a Wavefront role by its ID.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the information about the role.
 * const example = wavefront.getRole({
 *     id: "role-id",
 * });
 * ```
 */
export declare function getRole(args: GetRoleArgs, opts?: pulumi.InvokeOptions): Promise<GetRoleResult>;
/**
 * A collection of arguments for invoking getRole.
 */
export interface GetRoleArgs {
    /**
     * The ID associated with the role data to be fetched.
     */
    id: string;
}
/**
 * A collection of values returned by getRole.
 */
export interface GetRoleResult {
    /**
     * Human-readable description of the role.
     */
    readonly description: string;
    /**
     * The ID of the role in Wavefront.
     */
    readonly id: string;
    /**
     * The name of the role in Wavefront.
     */
    readonly name: string;
    /**
     * The list of permissions associated with role.
     */
    readonly permissions: string[];
}
/**
 * Use this data source to get information about a Wavefront role by its ID.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the information about the role.
 * const example = wavefront.getRole({
 *     id: "role-id",
 * });
 * ```
 */
export declare function getRoleOutput(args: GetRoleOutputArgs, opts?: pulumi.InvokeOptions): pulumi.Output<GetRoleResult>;
/**
 * A collection of arguments for invoking getRole.
 */
export interface GetRoleOutputArgs {
    /**
     * The ID associated with the role data to be fetched.
     */
    id: pulumi.Input<string>;
}
